// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `Specification ontology` vocabulary
//!
//! This module requires `ns-spec` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**|Specification ontology|
//! |**Prefix**|spec|
//! |**Namespace base IRI**|<http://www.w3.org/ns/spec#>|
//! |**Description**|Specification ontology.|
//! |**Is defined by**|<https://www.w3.org/ns/spec>|
//!

use crate::namespace;

namespace!(
    "http://www.w3.org/ns/spec#",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `Client`: 
    Client, "Client",
    /// `MAY`: 
    MAY, "MAY",
    /// `MUST`: 
    MUST, "MUST",
    /// `MUST-NOT`: 
    MUST_NOT, "MUST-NOT",
    /// `OPTIONAL`: 
    OPTIONAL, "OPTIONAL",
    /// `RECOMMENDED`: 
    RECOMMENDED, "RECOMMENDED",
    /// `REQUIRED`: 
    REQUIRED, "REQUIRED",
    /// `SHALL`: 
    SHALL, "SHALL",
    /// `SHALL-NOT`: 
    SHALL_NOT, "SHALL-NOT",
    /// `SHOULD`: 
    SHOULD, "SHOULD",
    /// `SHOULD-NOT`: 
    SHOULD_NOT, "SHOULD-NOT",
    /// `Server`: 
    Server, "Server",
    /// `requirement`: 
    requirement, "requirement",
    /// `requirementLevel`: 
    requirementLevel, "requirementLevel",
    /// `requirementSubject`: 
    requirementSubject, "requirementSubject",
    /// `statement`: 
    statement, "statement"
);
